@@ -16,34 +16,34 @@ from datetime import datetime
 from typing import Any, Dict, List
 
 from .literals import (
-    AggregationType,
-    ConnectionMode,
-    ConnectorType,
-    DatadogConnectorOperator,
-    DataPullMode,
-    DynatraceConnectorOperator,
-    ExecutionStatus,
-    FileType,
-    FlowStatus,
-    GoogleAnalyticsConnectorOperator,
-    InforNexusConnectorOperator,
-    MarketoConnectorOperator,
-    Operator,
-    OperatorPropertiesKeys,
-    PrefixFormat,
-    PrefixType,
-    S3ConnectorOperator,
-    SalesforceConnectorOperator,
-    ScheduleFrequencyType,
-    ServiceNowConnectorOperator,
-    SingularConnectorOperator,
-    SlackConnectorOperator,
-    TaskType,
-    TrendmicroConnectorOperator,
-    TriggerType,
-    VeevaConnectorOperator,
-    WriteOperationType,
-    ZendeskConnectorOperator,
+    AggregationTypeType,
+    ConnectionModeType,
+    ConnectorTypeType,
+    DatadogConnectorOperatorType,
+    DataPullModeType,
+    DynatraceConnectorOperatorType,
+    ExecutionStatusType,
+    FileTypeType,
+    FlowStatusType,
+    GoogleAnalyticsConnectorOperatorType,
+    InforNexusConnectorOperatorType,
+    MarketoConnectorOperatorType,
+    OperatorPropertiesKeysType,
+    OperatorType,
+    PrefixFormatType,
+    PrefixTypeType,
+    S3ConnectorOperatorType,
+    SalesforceConnectorOperatorType,
+    ScheduleFrequencyTypeType,
+    ServiceNowConnectorOperatorType,
+    SingularConnectorOperatorType,
+    SlackConnectorOperatorType,
+    TaskTypeType,
+    TrendmicroConnectorOperatorType,
+    TriggerTypeType,
+    VeevaConnectorOperatorType,
+    WriteOperationTypeType,
+    ZendeskConnectorOperatorType,
 )
 
 if sys.version_info >= (3, 8):
@@ -165,7 +165,7 @@ __all__ = (
 AggregationConfigTypeDef = TypedDict(
     "AggregationConfigTypeDef",
     {
-        "aggregationType": AggregationType,
+        "aggregationType": AggregationTypeType,
     },
     total=False,
 )
@@ -190,11 +190,11 @@ ConnectorConfigurationTypeDef = TypedDict(
     {
         "canUseAsSource": bool,
         "canUseAsDestination": bool,
-        "supportedDestinationConnectors": List[ConnectorType],
-        "supportedSchedulingFrequencies": List[ScheduleFrequencyType],
+        "supportedDestinationConnectors": List[ConnectorTypeType],
+        "supportedSchedulingFrequencies": List[ScheduleFrequencyTypeType],
         "isPrivateLinkEnabled": bool,
         "isPrivateLinkEndpointUrlRequired": bool,
-        "supportedTriggerTypes": List[TriggerType],
+        "supportedTriggerTypes": List[TriggerTypeType],
         "connectorMetadata": "ConnectorMetadataTypeDef",
     },
     total=False,
@@ -285,19 +285,19 @@ ConnectorOperatorTypeDef = TypedDict(
     "ConnectorOperatorTypeDef",
     {
         "Amplitude": Literal["BETWEEN"],
-        "Datadog": DatadogConnectorOperator,
-        "Dynatrace": DynatraceConnectorOperator,
-        "GoogleAnalytics": GoogleAnalyticsConnectorOperator,
-        "InforNexus": InforNexusConnectorOperator,
-        "Marketo": MarketoConnectorOperator,
-        "S3": S3ConnectorOperator,
-        "Salesforce": SalesforceConnectorOperator,
-        "ServiceNow": ServiceNowConnectorOperator,
-        "Singular": SingularConnectorOperator,
-        "Slack": SlackConnectorOperator,
-        "Trendmicro": TrendmicroConnectorOperator,
-        "Veeva": VeevaConnectorOperator,
-        "Zendesk": ZendeskConnectorOperator,
+        "Datadog": DatadogConnectorOperatorType,
+        "Dynatrace": DynatraceConnectorOperatorType,
+        "GoogleAnalytics": GoogleAnalyticsConnectorOperatorType,
+        "InforNexus": InforNexusConnectorOperatorType,
+        "Marketo": MarketoConnectorOperatorType,
+        "S3": S3ConnectorOperatorType,
+        "Salesforce": SalesforceConnectorOperatorType,
+        "ServiceNow": ServiceNowConnectorOperatorType,
+        "Singular": SingularConnectorOperatorType,
+        "Slack": SlackConnectorOperatorType,
+        "Trendmicro": TrendmicroConnectorOperatorType,
+        "Veeva": VeevaConnectorOperatorType,
+        "Zendesk": ZendeskConnectorOperatorType,
     },
     total=False,
 )
@@ -361,8 +361,8 @@ ConnectorProfileTypeDef = TypedDict(
     {
         "connectorProfileArn": str,
         "connectorProfileName": str,
-        "connectorType": ConnectorType,
-        "connectionMode": ConnectionMode,
+        "connectorType": ConnectorTypeType,
+        "connectionMode": ConnectionModeType,
         "credentialsArn": str,
         "connectorProfileProperties": "ConnectorProfilePropertiesTypeDef",
         "createdAt": datetime,
@@ -383,7 +383,7 @@ CreateFlowResponseTypeDef = TypedDict(
     "CreateFlowResponseTypeDef",
     {
         "flowArn": str,
-        "flowStatus": FlowStatus,
+        "flowStatus": FlowStatusType,
     },
     total=False,
 )
@@ -451,7 +451,7 @@ DescribeConnectorProfilesResponseTypeDef = TypedDict(
 DescribeConnectorsResponseTypeDef = TypedDict(
     "DescribeConnectorsResponseTypeDef",
     {
-        "connectorConfigurations": Dict[ConnectorType, "ConnectorConfigurationTypeDef"],
+        "connectorConfigurations": Dict[ConnectorTypeType, "ConnectorConfigurationTypeDef"],
         "nextToken": str,
     },
     total=False,
@@ -473,7 +473,7 @@ DescribeFlowResponseTypeDef = TypedDict(
         "description": str,
         "flowName": str,
         "kmsArn": str,
-        "flowStatus": FlowStatus,
+        "flowStatus": FlowStatusType,
         "flowStatusMessage": str,
         "sourceFlowConfig": "SourceFlowConfigTypeDef",
         "destinationFlowConfigList": List["DestinationFlowConfigTypeDef"],
@@ -513,7 +513,7 @@ DestinationFieldPropertiesTypeDef = TypedDict(
         "isNullable": bool,
         "isUpsertable": bool,
         "isUpdatable": bool,
-        "supportedWriteOperations": List[WriteOperationType],
+        "supportedWriteOperations": List[WriteOperationTypeType],
     },
     total=False,
 )
@@ -521,7 +521,7 @@ DestinationFieldPropertiesTypeDef = TypedDict(
 _RequiredDestinationFlowConfigTypeDef = TypedDict(
     "_RequiredDestinationFlowConfigTypeDef",
     {
-        "connectorType": ConnectorType,
+        "connectorType": ConnectorTypeType,
         "destinationConnectorProperties": "DestinationConnectorPropertiesTypeDef",
     },
 )
@@ -607,7 +607,7 @@ ExecutionDetailsTypeDef = TypedDict(
     {
         "mostRecentExecutionMessage": str,
         "mostRecentExecutionTime": datetime,
-        "mostRecentExecutionStatus": ExecutionStatus,
+        "mostRecentExecutionStatus": ExecutionStatusType,
     },
     total=False,
 )
@@ -616,7 +616,7 @@ ExecutionRecordTypeDef = TypedDict(
     "ExecutionRecordTypeDef",
     {
         "executionId": str,
-        "executionStatus": ExecutionStatus,
+        "executionStatus": ExecutionStatusType,
         "executionResult": "ExecutionResultTypeDef",
         "startedAt": datetime,
         "lastUpdatedAt": datetime,
@@ -641,7 +641,7 @@ _RequiredFieldTypeDetailsTypeDef = TypedDict(
     "_RequiredFieldTypeDetailsTypeDef",
     {
         "fieldType": str,
-        "filterOperators": List[Operator],
+        "filterOperators": List[OperatorType],
     },
 )
 _OptionalFieldTypeDetailsTypeDef = TypedDict(
@@ -663,10 +663,10 @@ FlowDefinitionTypeDef = TypedDict(
         "flowArn": str,
         "description": str,
         "flowName": str,
-        "flowStatus": FlowStatus,
-        "sourceConnectorType": ConnectorType,
-        "destinationConnectorType": ConnectorType,
-        "triggerType": TriggerType,
+        "flowStatus": FlowStatusType,
+        "sourceConnectorType": ConnectorTypeType,
+        "destinationConnectorType": ConnectorTypeType,
+        "triggerType": TriggerTypeType,
         "createdAt": datetime,
         "lastUpdatedAt": datetime,
         "createdBy": str,
@@ -853,8 +853,8 @@ MarketoSourcePropertiesTypeDef = TypedDict(
 PrefixConfigTypeDef = TypedDict(
     "PrefixConfigTypeDef",
     {
-        "prefixType": PrefixType,
-        "prefixFormat": PrefixFormat,
+        "prefixType": PrefixTypeType,
+        "prefixFormat": PrefixFormatType,
     },
     total=False,
 )
@@ -939,7 +939,7 @@ class S3DestinationPropertiesTypeDef(
 S3OutputFormatConfigTypeDef = TypedDict(
     "S3OutputFormatConfigTypeDef",
     {
-        "fileType": FileType,
+        "fileType": FileTypeType,
         "prefixConfig": "PrefixConfigTypeDef",
         "aggregationConfig": "AggregationConfigTypeDef",
     },
@@ -998,7 +998,7 @@ _OptionalSalesforceDestinationPropertiesTypeDef = TypedDict(
     {
         "idFieldNames": List[str],
         "errorHandlingConfig": "ErrorHandlingConfigTypeDef",
-        "writeOperationType": WriteOperationType,
+        "writeOperationType": WriteOperationTypeType,
     },
     total=False,
 )
@@ -1049,7 +1049,7 @@ _RequiredScheduledTriggerPropertiesTypeDef = TypedDict(
 _OptionalScheduledTriggerPropertiesTypeDef = TypedDict(
     "_OptionalScheduledTriggerPropertiesTypeDef",
     {
-        "dataPullMode": DataPullMode,
+        "dataPullMode": DataPullModeType,
         "scheduleStartTime": datetime,
         "scheduleEndTime": datetime,
         "timezone": str,
@@ -1247,7 +1247,7 @@ SourceFieldPropertiesTypeDef = TypedDict(
 _RequiredSourceFlowConfigTypeDef = TypedDict(
     "_RequiredSourceFlowConfigTypeDef",
     {
-        "connectorType": ConnectorType,
+        "connectorType": ConnectorTypeType,
         "sourceConnectorProperties": "SourceConnectorPropertiesTypeDef",
     },
 )
@@ -1269,7 +1269,7 @@ StartFlowResponseTypeDef = TypedDict(
     "StartFlowResponseTypeDef",
     {
         "flowArn": str,
-        "flowStatus": FlowStatus,
+        "flowStatus": FlowStatusType,
         "executionId": str,
     },
     total=False,
@@ -1279,7 +1279,7 @@ StopFlowResponseTypeDef = TypedDict(
     "StopFlowResponseTypeDef",
     {
         "flowArn": str,
-        "flowStatus": FlowStatus,
+        "flowStatus": FlowStatusType,
     },
     total=False,
 )
@@ -1295,7 +1295,7 @@ _RequiredTaskTypeDef = TypedDict(
     "_RequiredTaskTypeDef",
     {
         "sourceFields": List[str],
-        "taskType": TaskType,
+        "taskType": TaskTypeType,
     },
 )
 _OptionalTaskTypeDef = TypedDict(
@@ -1303,7 +1303,7 @@ _OptionalTaskTypeDef = TypedDict(
     {
         "connectorOperator": "ConnectorOperatorTypeDef",
         "destinationField": str,
-        "taskProperties": Dict[OperatorPropertiesKeys, str],
+        "taskProperties": Dict[OperatorPropertiesKeysType, str],
     },
     total=False,
 )
@@ -1330,7 +1330,7 @@ TrendmicroSourcePropertiesTypeDef = TypedDict(
 _RequiredTriggerConfigTypeDef = TypedDict(
     "_RequiredTriggerConfigTypeDef",
     {
-        "triggerType": TriggerType,
+        "triggerType": TriggerTypeType,
     },
 )
 _OptionalTriggerConfigTypeDef = TypedDict(
@@ -1365,7 +1365,7 @@ UpdateConnectorProfileResponseTypeDef = TypedDict(
 UpdateFlowResponseTypeDef = TypedDict(
     "UpdateFlowResponseTypeDef",
     {
-        "flowStatus": FlowStatus,
+        "flowStatus": FlowStatusType,
     },
     total=False,
 )
@@ -1401,7 +1401,7 @@ _RequiredUpsolverS3OutputFormatConfigTypeDef = TypedDict(
 _OptionalUpsolverS3OutputFormatConfigTypeDef = TypedDict(
     "_OptionalUpsolverS3OutputFormatConfigTypeDef",
     {
-        "fileType": FileType,
+        "fileType": FileTypeType,
         "aggregationConfig": "AggregationConfigTypeDef",
     },
     total=False,
@@ -1478,7 +1478,7 @@ _OptionalZendeskDestinationPropertiesTypeDef = TypedDict(
     {
         "idFieldNames": List[str],
         "errorHandlingConfig": "ErrorHandlingConfigTypeDef",
-        "writeOperationType": WriteOperationType,
+        "writeOperationType": WriteOperationTypeType,
     },
     total=False,
 )
